clear all;



time = 0:0.01:20;

sine_wave = sin( time );
sine_wave_90 = sin( time + pi/2.0 );

square_wave = ( sine_wave > 0 );
square_wave_90 = ( sine_wave_90 > 0 );


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% square wave


figure(1);
clf;

plot( time, square_wave, 'b', 'LineWidth' ,6 );
grid on;
xlabel('time');
ylabel('magnitude');
xlim([0,20]);
ylim([-1, 2.0]);



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% square wave quadrature

figure(2);
clf;

plot( time, square_wave + 0.6 , 'b', 'LineWidth' ,6 ); hold on;
plot( time, square_wave_90 -0.6, 'r', 'LineWidth' ,6 );
grid on;
xlabel('time');
ylabel('magnitude');
xlim([0,20]);
ylim([-1, 2.0]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% sine wave quadrature

figure(3);
clf;

plot( time, sine_wave + 1.5 , 'b', 'LineWidth' ,6 ); hold on;
plot( time, sine_wave_90 -1.5, 'r', 'LineWidth' ,6 );
grid on;
xlabel('time');
ylabel('magnitude');
xlim([0,20]);
ylim([-3, 3.0]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% sine wave quadrature

figure(4);
clf;

plot( time, sine_wave + 1.5 , 'b', 'LineWidth' ,6 ); hold on;
plot( time, sine_wave_90 -1.5, 'r', 'LineWidth' ,6 );
grid on;
xlabel('time');
ylabel('magnitude');
xlim([pi/2-.2,5/2*pi+.2]);
ylim([-3, 3.0]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% sine wave quadrature resolver

figure(5);
clf;

resolver_time = 0:0.001:0.3;

resolver_carrier = sin( resolver_time .*400 );

sine_wave = sin( resolver_time * 20 );
sine_wave_90 = sin( resolver_time * 20 + pi/2.0 );


subplot(1,2,1); plot( resolver_time, sine_wave + 1.5, 'b', 'LineWidth' ,3 ); hold on;
subplot(1,2,1); plot( resolver_time, sine_wave_90 -1.5 , 'b', 'LineWidth' ,3 ); hold on;
grid on;
xlabel('time');
ylabel('magnitude');
xlim([0,0.3]);
ylim([-3, 3.0]);


subplot(1,2,2); plot( resolver_time, resolver_carrier.*sine_wave + 1.5, 'b', 'LineWidth' ,3 ); hold on;
subplot(1,2,2); plot( resolver_time, sine_wave + 1.5, '--r', 'LineWidth' ,1 ); hold on;
subplot(1,2,2); plot( resolver_time, -sine_wave + 1.5, '--r', 'LineWidth' ,1 ); hold on;

subplot(1,2,2); plot( resolver_time, resolver_carrier.*sine_wave_90 -1.5 , 'b', 'LineWidth' ,3 ); hold on;
subplot(1,2,2); plot( resolver_time, sine_wave_90 - 1.5, '--r', 'LineWidth' ,1 ); hold on;
subplot(1,2,2); plot( resolver_time, -sine_wave_90 - 1.5, '--r', 'LineWidth' ,1 ); hold on;
grid on;
xlabel('time');
ylabel('magnitude');
xlim([0,0.3]);
ylim([-3, 3.0]);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% constant angle sine wave quadrature resolver
figure(5);
clf;

resolver_time = 0:0.001:0.3;

resolver_carrier = sin( resolver_time .*400 );

sine_wave = sin( resolver_time * 0.00001 + pi/7 );
sine_wave_90 = sin( resolver_time * 0.00001 + pi/2.0 + pi/7 );


subplot(1,2,1); plot( resolver_time, sine_wave + 1.5, 'b', 'LineWidth' ,3 ); hold on;
subplot(1,2,1); plot( resolver_time, sine_wave_90 -1.5 , 'b', 'LineWidth' ,3 ); hold on;
grid on;
xlabel('time');
ylabel('magnitude');
xlim([0,0.3]);
ylim([-3, 3.0]);


subplot(1,2,2); plot( resolver_time, resolver_carrier.*sine_wave + 1.5, 'b', 'LineWidth' ,3 ); hold on;
subplot(1,2,2); plot( resolver_time, sine_wave + 1.5, '--r', 'LineWidth' ,1 ); hold on;
subplot(1,2,2); plot( resolver_time, -sine_wave + 1.5, '--r', 'LineWidth' ,1 ); hold on;

subplot(1,2,2); plot( resolver_time, resolver_carrier.*sine_wave_90 -1.5 , 'b', 'LineWidth' ,3 ); hold on;
subplot(1,2,2); plot( resolver_time, sine_wave_90 - 1.5, '--r', 'LineWidth' ,1 ); hold on;
subplot(1,2,2); plot( resolver_time, -sine_wave_90 - 1.5, '--r', 'LineWidth' ,1 ); hold on;
grid on;
xlabel('time');
ylabel('magnitude');
xlim([0,0.3]);
ylim([-3, 3.0]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% resolver

figure(6);
clf;

resolver_time = 0:0.001:0.1;

resolver_carrier = sin( resolver_time .*400 );
scale_a = sin( pi/3 );
scale_b = cos( pi/3 );

subplot(2,2,1); plot( [0,0.1], [0,0] + 2.0, 'k', 'LineWidth' ,2 ); hold on;
subplot(2,2,1); plot( [0,0.1], [0,0] + 0.0, 'k', 'LineWidth' ,2 ); hold on;
subplot(2,2,1); plot( [0,0.1], [0,0] - 2.0, 'k', 'LineWidth' ,2 ); hold on;

subplot(2,2,1); plot( resolver_time, resolver_carrier + 2.0, 'b', 'LineWidth' ,3 ); hold on;
subplot(2,2,1); plot( resolver_time, resolver_carrier*scale_a + 0.0, 'b', 'LineWidth' ,3 ); hold on;
subplot(2,2,1); plot( resolver_time, resolver_carrier*scale_b - 2.0, 'b', 'LineWidth' ,3 ); hold on;

grid on;
xlabel('time');
xlim([0,0.1]);
ylim([-3, 4.0]);

%%%%%%%%%%%%%%%

scale_a = sin( pi/3 + pi/2);
scale_b = cos( pi/3 + pi/2);

subplot(2,2,2); plot( [0,0.1], [0,0] + 2.0, 'k', 'LineWidth' ,2 ); hold on;
subplot(2,2,2); plot( [0,0.1], [0,0] + 0.0, 'k', 'LineWidth' ,2 ); hold on;
subplot(2,2,2); plot( [0,0.1], [0,0] - 2.0, 'k', 'LineWidth' ,2 ); hold on;

subplot(2,2,2); plot( resolver_time, resolver_carrier + 2.0, 'b', 'LineWidth' ,3 ); hold on;
subplot(2,2,2); plot( resolver_time, resolver_carrier*scale_a + 0.0, 'b', 'LineWidth' ,3 ); hold on;
subplot(2,2,2); plot( resolver_time, resolver_carrier*scale_b - 2.0, 'b', 'LineWidth' ,3 ); hold on;

grid on;
xlabel('time');
xlim([0,0.1]);
ylim([-3, 4.0]);

%%%%%%%%%%%%%%%

scale_a = sin( pi/3 + 2*pi/2);
scale_b = cos( pi/3 + 2*pi/2);

subplot(2,2,3); plot( [0,0.1], [0,0] + 2.0, 'k', 'LineWidth' ,2 ); hold on;
subplot(2,2,3); plot( [0,0.1], [0,0] + 0.0, 'k', 'LineWidth' ,2 ); hold on;
subplot(2,2,3); plot( [0,0.1], [0,0] - 2.0, 'k', 'LineWidth' ,2 ); hold on;

subplot(2,2,3); plot( resolver_time, resolver_carrier + 2.0, 'b', 'LineWidth' ,3 ); hold on;
subplot(2,2,3); plot( resolver_time, resolver_carrier*scale_a + 0.0, 'b', 'LineWidth' ,3 ); hold on;
subplot(2,2,3); plot( resolver_time, resolver_carrier*scale_b - 2.0, 'b', 'LineWidth' ,3 ); hold on;

grid on;
xlabel('time');
xlim([0,0.1]);
ylim([-3, 4.0]);

%%%%%%%%%%%%%%%

scale_a = sin( pi/3 + 3*pi/2);
scale_b = cos( pi/3 + 3*pi/2);

subplot(2,2,4); plot( [0,0.1], [0,0] + 2.0, 'k', 'LineWidth' ,2 ); hold on;
subplot(2,2,4); plot( [0,0.1], [0,0] + 0.0, 'k', 'LineWidth' ,2 ); hold on;
subplot(2,2,4); plot( [0,0.1], [0,0] - 2.0, 'k', 'LineWidth' ,2 ); hold on;

subplot(2,2,4); plot( resolver_time, resolver_carrier + 2.0, 'b', 'LineWidth' ,3 ); hold on;
subplot(2,2,4); plot( resolver_time, resolver_carrier*scale_a + 0.0, 'b', 'LineWidth' ,3 ); hold on;
subplot(2,2,4); plot( resolver_time, resolver_carrier*scale_b - 2.0, 'b', 'LineWidth' ,3 ); hold on;

grid on;
xlabel('time');
xlim([0,0.1]);
ylim([-3, 4.0]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% single vs differential


figure(7);
clf;

time_diff = 0:0.1:20;
num_time = size( time_diff );
size_time = num_time(2);

sine_wave_diff = sin( time_diff );
square_wave_diff = ( sine_wave_diff > 0 );
rand_sq_wave = 0.7*rand(1,size_time) - 0.35;

subplot(1,3,1); plot( time_diff, square_wave_diff, 'b', 'LineWidth' ,3 );
grid on;
xlabel('time');
ylabel('singal');
xlim([0,20]);
ylim([-0.5, 1.5]);

subplot(1,3,2); plot( time_diff, rand_sq_wave, 'b', 'LineWidth' ,3 );
grid on;
xlabel('time');
ylabel('noise');
xlim([0,20]);
ylim([-0.5, 0.5]);

subplot(1,3,3); plot( time_diff, square_wave_diff + rand_sq_wave, 'b', 'LineWidth' ,3 );
grid on;
xlabel('time');
ylabel('singal + noise ');
xlim([0,20]);
ylim([-0.5, 1.5]);



figure(8);
clf;


subplot(1,3,1); plot( time_diff, -square_wave_diff, 'b', 'LineWidth' ,3 );
grid on;
xlabel('time');
ylabel('singal');
xlim([0,20]);
ylim([-1.5, 0.5]);

subplot(1,3,2); plot( time_diff, rand_sq_wave, 'b', 'LineWidth' ,3 );
grid on;
xlabel('time');
ylabel('noise');
xlim([0,20]);
ylim([-0.5, 0.5]);

subplot(1,3,3); plot( time_diff, -square_wave_diff + rand_sq_wave, 'b', 'LineWidth' ,3 );
grid on;
xlabel('time');
ylabel('singal + noise ');
xlim([0,20]);
ylim([-1.5, 0.5]);




